@@ -8,6 +8,9 @@ use rand::os::OsRng;
 use rand::Rng;
 use std::time::Instant;
 
+#[cfg(test)]
+const SIDE: u8 = 3;
+#[cfg(not(test))]
 const SIDE: u8 = 4;
 const LIMIT: usize = (SIDE * SIDE) as usize;
 
@@ -157,6 +160,12 @@ impl Default for Game {
     }
 }
 
+#[test]
+fn test() {
+    // main() already contains checks.
+    main();
+}
+
 fn main() {
     let b = Game::shuffled();
     println!("{:?}", b);
